sprig

package
v1.14.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 7, 2025 License: ISC Imports: 32 Imported by: 1

Documentation

Overview

Package sprig provides template functions compatible with Masterminds/sprig.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FuncMap

func FuncMap() template.FuncMap

FuncMap returns the standard function map for templates. This is an alias for TxtFuncMap.

func GenericFuncMap

func GenericFuncMap() map[string]interface{}

GenericFuncMap returns a copy of the basic function map as a map[string]interface{}.

func HermeticHtmlFuncMap

func HermeticHtmlFuncMap() htmltemplate.FuncMap

HermeticHtmlFuncMap returns a function map with only repeatable HTML template functions. Functions that depend on time, randomness, or environment are excluded.

func HermeticTxtFuncMap

func HermeticTxtFuncMap() template.FuncMap

HermeticTxtFuncMap returns a function map with only repeatable text template functions. Functions that depend on time, randomness, or environment are excluded.

func HtmlFuncMap

func HtmlFuncMap() htmltemplate.FuncMap

HtmlFuncMap returns a function map for HTML templates.

func TxtFuncMap

func TxtFuncMap() template.FuncMap

TxtFuncMap returns a function map for text templates.

Types

This section is empty.

Jump to