Documentation
¶
Overview ¶
Package sprig provides template functions compatible with Masterminds/sprig.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FuncMap ¶
FuncMap returns the standard function map for templates. This is an alias for TxtFuncMap.
func GenericFuncMap ¶
func GenericFuncMap() map[string]interface{}
GenericFuncMap returns a copy of the basic function map as a map[string]interface{}.
func HermeticHtmlFuncMap ¶
func HermeticHtmlFuncMap() htmltemplate.FuncMap
HermeticHtmlFuncMap returns a function map with only repeatable HTML template functions. Functions that depend on time, randomness, or environment are excluded.
func HermeticTxtFuncMap ¶
HermeticTxtFuncMap returns a function map with only repeatable text template functions. Functions that depend on time, randomness, or environment are excluded.
func HtmlFuncMap ¶
func HtmlFuncMap() htmltemplate.FuncMap
HtmlFuncMap returns a function map for HTML templates.
func TxtFuncMap ¶
TxtFuncMap returns a function map for text templates.
Types ¶
This section is empty.